<?php
// vim: foldmethod=marker
/**
 *  base include file for SimpleTest
 *  @author halt <halt@project-p.jp>
 *  @package    SimpleTest
 *  @subpackage UnitTester
 *  @version    $Id: reporter.php,v 1.33 2004/11/29 04:35:49 lastcraft Exp $
 */

/**#@+
 *  include other SimpleTest class files
 */
require_once(dirname(__FILE__) . '/scorer.php');
require_once(dirname(__FILE__) . '/reporter.php');

/**#@-*/
    
    /**
     *    Sample minimal test displayer. Generates only
     *    failure messages and a pass count.
     *    @package SimpleTest
     *    @subpackage UnitTester
     */
    class PHPInfoReporter extends SimpleReporter {
        
        var $_character_set;
        
        /**
         *    Does nothing yet. The first output will
         *    be sent on the first test start. For use
         *    by a web browser.
         *    @access public
         */
        function PHPInfoReporter($character_set = 'EUC-JP') {
            $this->SimpleReporter();
            $this->_character_set = $character_set;
        }
    
        //{{{ paintHeader
        /**
         *    Paints the top of the web page setting the
         *    title to the name of the starting test.
         *    @param string $test_name      Name class of test.
         *    @access public
         */
        function paintHeader($test_name) {
            
            $this->sendNoCacheHeaders();
            
            print '<html lang="ja">'."\n";
            print "<head>\n";
            print "<title>$test_name</title>\n";
            print "<meta http-equiv=\"Content-Type\" content=\"text/html; charset=" .
                    $this->_character_set . "\">\n";
            print "<style type=\"text/css\">\n";
            print $this->_getCss() . "\n";
            print "</style>\n";
            print "</head>\n<body>\n";
            print "<h1>$test_name</h1>\n";
            flush();
        }
        //}}}

        //{{{ sendNoCacheHeaders
        /**
         *    Send the headers necessary to ensure the page is
         *    reloaded on every request. Otherwise you could be
         *    scratching your head over out of date test data.
         *    @access public
         *    @static
         */
        function sendNoCacheHeaders() {
            if (! headers_sent()) {
                header("Expires: Mon, 26 Jul 1997 05:00:00 GMT");
                header("Last-Modified: " . gmdate("D, d M Y H:i:s") . " GMT");
                header("Cache-Control: no-store, no-cache, must-revalidate");
                header("Cache-Control: post-check=0, pre-check=0", false);
                header("Pragma: no-cache");
            }
        }
        //}}}
        
        //{{{ _getCSS
        /**
         *    Paints the CSS. Add additional styles here.
         *    @return string            CSS code as text.
         *    @access protected
         */
        function _getCss() {
$css = <<< EOD
body{
    background-color:white;
    color:black;
    text-align:center;
}

.fail{
    color: red;
}

pre{
    background-color: lightgray;
}

.case{
    border:solid 1px black;
    width:600px;
    margin:auto;
    margin-top:1em;
    margin-bottom:1em;
}

h1 {
    font-size: 150%;
    font-weight: bold;
    background-color: #9999cc;
    border:1px solid black;
    background-image:url("?=PHPE9568F34-D428-11d2-A769-00AA001ACF42");
    background-repeat: no-repeat;
    background-position: right;
    color: #000000;
    width: 600px;
    height: 67px;
    text-align:left;
    margin:auto;
}

h2 {
    font-weight:bold;
    text-align:center;
}

h3 {
    background-color: #9999cc;
    border-bottom:1px solid black;
    margin:0px;
    padding:0.5em;
    text-align:left;
}

.footer {
    background-color: #cccccc;
    border:1px solid black;
    width:600px;
    margin:auto;
}

table.testcase{
    margin:auto;
    text-align:left;
}

th{
    background-color:#ccccff;
    border-right:1px solid black;
    border-top:1px solid black;
    font-weight:bold;
    padding:0.5em;
    margin:auto;
    width:50%;
}

td{
    background-color:#cccccc;
    border-top:1px solid black;
    margin:auto;
    padding:0.5em;
}

EOD;
            return $css;
        }
        //}}}
        
        //{{{ paintFooter
        /**
         *    Paints the end of the test with a summary of
         *    the passes and failures.
         *    @param string $test_name        Name class of test.
         *    @access public
         */
        function paintFooter($test_name) {
            $colour = ($this->getFailCount() + $this->getExceptionCount() > 0 ? "red" : "green");
            print '<h2><a name="Result">Result</a></h2>';
            print '<div class="footer">';
            print $this->getTestCaseProgress() . "/" . $this->getTestCaseCount();
            print " test cases complete:\n";
            print "<strong>" . $this->getPassCount() . "</strong> passes, ";
            print "<strong>" . $this->getFailCount() . "</strong> fails and ";
            print "<strong>" . $this->getExceptionCount() . "</strong> exceptions.";
            print "</div>\n";
            print "</body>\n</html>\n";
        }
        //}}}

        //{{{ paintPass
        /**
         * Paint Pass
         *
         */
        function paintPass($message)
        {
            parent::paintPass($message);
            
            $test_list = $this->getTestList();
            print("<tr>\n");
            print('<th>'.$test_list[2].'</th>');
            print('<td>'.$message.'</td>');
            print("</tr>\n");
        }
        //}}}
        
        //{{{ paintFail
        /**
         *    Paints the test failure with a breadcrumbs
         *    trail of the nesting test suites below the
         *    top level test.
         *    @param string $message    Failure message displayed in
         *                              the context of the other tests.
         *    @access public
         */
        function paintFail($message) {
            
            parent::paintFail($message);
            
            $test_list = $this->getTestList();
            
            print("<tr>\n");
            print ('<th>'.$test_list[2].'</th>');
            print ("<td class=\"fail\">");
            print ("<strong>Fail</strong> ".$message);
            print ("</td>");
            print("</tr>\n");
        
        }
        //}}}za
        
        //{{{ paintExeption
        /**
         *    Paints a PHP error or exception.
         *    @param string $message        Message is ignored.
         *    @access public
         *    @abstract
         */
        function paintException($message) {
            parent::paintException($message);
            $breadcrumb = $this->getTestList();
            
            print('<tr>');
            print ('<th>'.$breadcrumb[2].'</th>');
            print "<td class=\"fail\">Exception ";
            array_shift($breadcrumb);
            print('<ul>');
            foreach( $breadcrumb as $crumb){
                print("<li>{$crumb}</li>");
            }
            print('</ul>');
            print "<strong>" . $this->_htmlEntities($message) . "</strong><br />\n";
            print('</td>');
            print('</tr>');
        }
        //}}}
        
        //{{{ paintFormattedMessage
        /**
         *    Paints formatted text such as dumped variables.
         *    @param string $message        Text to show.
         *    @access public
         */
        function paintFormattedMessage($message) {
            print '<pre>' . $this->_htmlEntities($message) . '</pre>';
        }
        //}}}
        
        //{{{ paintCaseStart
        /**
         * paintCaseStart
         *
         */
        function paintCaseStart($test_name)
        {
            parent::paintCaseStart($test_name);
            print('<div class="case">'."\n");
            print('<h3>'.$test_name.'</h3>');
            print('<table>');
        }
        //}}}

        //{{{ paintCaseEnd
        /**
         * paintCaseEnd
         *
         */
        function paintCaseEnd($test_name)
        {
            parent::paintCaseEnd($test_name);
            print('</table>');
            print('</div>');
        }
        //}}}
        
        //{{{ _htmlEntities
        /**
         *    Character set adjusted entity conversion.
         *    @param string $message    Plain text or Unicode message.
         *    @return string            Browser readable message.
         *    @access protected
         */
        function _htmlEntities($message) {
            return htmlentities($message, ENT_COMPAT, $this->_character_set);
        }
        //}}}

    }
?>
